@@ -501,8 +501,7 @@ void Titraqform::setupMenubar(void)
     if (pHelppopup == NULL) // Sanity check
         throw Genexcept("Main window help popup creation failed.");
     m_pMenubar->insertItem(trUtf8("&Help"), pHelppopup);
-    nMenuid = pHelppopup->insertItem(trUtf8("&Contents"), this, SLOT(helpContents()), Key_F1);
-    pHelppopup->setItemEnabled(nMenuid, false);
+    pHelppopup->insertItem(trUtf8("&Contents"), this, SLOT(helpContents()), Key_F1);
     pHelppopup->insertSeparator();
     pHelppopup->insertItem(trUtf8("About &AS-GUI"), this, SLOT(aboutTitraq()));
     pHelppopup->insertItem(trUtf8("About &OSSP"), this, SLOT(aboutOSSP()));
@@ -888,15 +887,20 @@ void Titraqform::setupEditlay(void)
         throw Genexcept("Main window task edit creation failed.");
     m_pTasks->insertStringList(*m_pTaskentries);
     m_pTasks->setCurrentText(NULL);
+    m_pTasks->setSizeLimit(TITRAQ_ACCTBOXHEIGHT);
     m_pTasks->setAutoCompletion(true);
     m_pTasks->setDuplicatesEnabled(false);
     m_pTasks->setEnabled(false);
 //    m_pTasks->setEditable(false);   // Only idiots define noneditable and autocompletion
 
     // Add an auto scroll bar if possible under current GUI style
-    if (m_pTasks->listBox())    // Motif style has no list box
+    if (m_pTasks->listBox()) {  // Motif style has no list box
+        int nPopupwidth = m_pTasks->listBox()->maxItemWidth();
+        nPopupwidth += m_pTasks->listBox()->horizontalScrollBar()->height();
+        m_pTasks->listBox()->setFixedWidth(nPopupwidth);
         m_pTasks->listBox()->setHScrollBarMode(QScrollView::Auto);
-//        m_pTasks->setMinimumWidth(m_pTasks->listBox()->maxItemWidth());
+        m_pTasks->listBox()->sort();
+    }
 
     // Whatsthis info for the task editor
     const char *kszTasktext = "Choose a <em>task account</em> by clicking on "
