@@ -342,7 +342,8 @@ void Titraqform::loadData(QTextStream &Tstream)
                 Qualistring Testuple = User + Guid + Rev + Date + Start;
                             Testuple += Finish + Amount + Account + Remark;
                 U32 Valcrc = Testuple.getCrc(); // Finally set the checksum to its new value
-                m_pMaintable->setText(nIter, TITRAQ_IDXCRC, "0x" + QString::number(Valcrc, 16));
+                QString Crcstr = QString::number(Valcrc, 16).rightJustify(8, '0');
+                m_pMaintable->setText(nIter, TITRAQ_IDXCRC, "0x" + Crcstr);
             }
         }
         else // if isEmpty()
