@@ -63,6 +63,7 @@
 #include "as_pref.h"            // For Preferences class
 #include "as_panel.h"           // For Prefpanel class
 #include "as_reportpanel.h"     // For Reportpanel class
+#include "as_helpanel.h"        // For Helpanel class
 #include "as_sfile.h"           // For Simplefile class
 #include "as_table.h"           // For TiTable class
 
@@ -809,6 +810,7 @@ void Titraqform::calcCrc(int nRow, int nCol)
     if (nCol != TITRAQ_IDXSTATUS && nCol != TITRAQ_IDXLINE \
                                  && m_pMaintable->numRows() > 0) {
         U32 Testcrc, Valcrc;
+        QString Crcstr;
         std::auto_ptr<Qualistring>pWholerow(new Qualistring);
         int nRealrow = -1;
 
@@ -836,8 +838,9 @@ void Titraqform::calcCrc(int nRow, int nCol)
                     *pWholerow += m_pMaintable->text(nRealrow, nIter);
 
             Valcrc = pWholerow->getCrc(); // Finally set the checksum to its new value
-            m_pMaintable->setText(nRealrow, TITRAQ_IDXCRC, "0x" + QString::number(Valcrc, 16));
-            m_pCrcedit->setText("0x" + QString::number(Valcrc, 16));
+            Crcstr = QString::number(Valcrc, 16).rightJustify(8, '0');
+            m_pMaintable->setText(nRealrow, TITRAQ_IDXCRC, "0x" + Crcstr);
+            m_pCrcedit->setText("0x" + Crcstr);
         }
     }
 }
@@ -1858,8 +1861,15 @@ void Titraqform::savePrefs(void)
 //
 void Titraqform::helpContents(void)
 {
-    Prototype Unimp;
-    Unimp.doMbox();
+    try { // Create and execute a new help contents window
+        std::auto_ptr<AS::Helpanel> pHelpcont(new AS::Helpanel(this, "Helpanel"));
+        pHelpcont->exec();
+        delete pHelpcont.release(); // Technically unnecessary, smart pointer
+    }
+    catch (Genexcept& Genex) {
+        Genex.reportErr();
+        return;
+    }
 }
 
 //
